@@ -1,6 +1,7 @@
 from typing import Dict, Any, Callable, Optional, Union, List
 
 # noinspection PyProtectedMember
+from mlflow.entities import RunStatus  # type: ignore
 from pyspark import keyword_only
 from pyspark.ml.param import Param
 from pyspark.sql import DataFrame
@@ -104,13 +105,24 @@ class FrameworkMappingLoader(FrameworkTransformer):
             ):
                 self.logger.info(f"Dropping view {automapper.view}")
                 df.sql_ctx.dropTempTable(tableName=automapper.view)
-
             try:
+                if self.progress_logger is not None:
+                    self.progress_logger.start_mlflow_run(
+                        run_name=str(automapper), is_nested=True
+                    )
+
                 automapper.transform(df=df)
+
+                if self.progress_logger is not None:
+                    self.progress_logger.end_mlflow_run()
             except Exception as e:
-                raise FrameworkMappingRunnerException(
-                    msg=f"Error running automapper {automapper.view}", exception=e
-                ) from e
+                error_msg = f"Error running automapper {automapper.view}"
+                if self.progress_logger is not None:
+                    self.progress_logger.log_exception(
+                        event_name=str(automapper), event_text=error_msg, ex=e
+                    )
+                    self.progress_logger.end_mlflow_run(status=RunStatus.FAILED)
+                raise FrameworkMappingRunnerException(msg=error_msg, exception=e) from e
 
         return df
 
